@@ -38,7 +38,7 @@ sde0f <- function(x) {
   # In case of series not varying, set v0 to 0
   # if (length(unique(x))>1) {
   if (0 != var(if (is.factor(x)) as.integer(x) else x)) {
-    m.ar <- ar(x)
+    m.ar <- stats::ar(x)
     v0 <- m.ar$var.pred / (1-sum(m.ar$ar))^2
   } else {
     v0 <- 0
@@ -80,12 +80,12 @@ calc_bin <- function(x, bins=bins) {
 #' @param labels optional vector of labels
 #' @return A factor
 #' @export
-gl_unq <- function (n, k, labels=1:n) {
+gl_unq <- function (n, k, labels=seq_len(n)) {
   x <- NULL
-  for (i in 1:n) {
+  for (i in seq_len(n)) {
     x <- append(x, rep(i, length.out=k[i]))
   }
-  x <- factor(x, levels=1:n, labels=labels)
+  x <- factor(x, levels=seq_len(n), labels=labels)
   return(x)
 }
 
@@ -148,7 +148,7 @@ ci <- function (D, thick_ci=c(0.05, 0.95), thin_ci=c(0.025, 0.975)) {
 plab <- function (parameter.name, match, subscripts = NULL) {
   # If no subscripts are passed, use generic ones
   if (is.null(subscripts)) {
-    ss <- paste("dim", 1:length(match), sep = ".")
+    ss <- paste("dim", seq_len(length(match)), sep = ".")
   } else {
     ss <- subscripts
   }
@@ -163,7 +163,7 @@ plab <- function (parameter.name, match, subscripts = NULL) {
   } else {
     lab.text <- "Label = "
   }
-  for (m in 1:length(match)) {
+  for (m in seq_len(length(match))) {
     if (m > 1) {
       eg.text <- paste0(eg.text, ", ")
       par.text <- paste0(par.text, ", ',', ")
@@ -171,7 +171,11 @@ plab <- function (parameter.name, match, subscripts = NULL) {
     }
     eg.text <- paste0(eg.text, ss[m], " = 1:", length(match[[m]]))
     par.text <- paste0(par.text, ss[m])
-    var.text <- paste0(var.text, " %>% dplyr::mutate(", names(match)[m], " = factor(", ss[m], ", label = ", match[m], "))")
+    if (length(unlist(match[m])) > 1) {
+      var.text <- paste0(var.text, " %>% dplyr::mutate(", names(match)[m], " = factor(", ss[m], ", labels = ", match[m], "))")
+    } else {
+      var.text <- paste0(var.text, " %>% dplyr::mutate(", names(match)[m], " = factor(", ss[m], ", labels = '", match[m], "'))")
+    }
     lab.text <- paste0(lab.text, names(match)[m])
   }
   eg.text <- paste0(eg.text, ")")
@@ -179,7 +183,6 @@ plab <- function (parameter.name, match, subscripts = NULL) {
   if (length(match) > 1) {
     lab.text <- paste0(lab.text, ", sep = ' : ')")
   }
-
   # Paste the final text together
   full.text <- eg.text
   full.text <- paste0(full.text, " %>% dplyr::mutate(", par.text, ")")
@@ -188,7 +191,6 @@ plab <- function (parameter.name, match, subscripts = NULL) {
   full.text <- paste0(full.text, " %>% dplyr::as_tibble()")
   full.text <- paste0(full.text, " %>% dplyr::mutate(Parameter = factor(Parameter))")
   full.text <- paste0(full.text, " %>% dplyr::mutate(Label = factor(Label))")
-
   # Evaluate the text and generate the data frame
   PL <- eval(parse(text = full.text))
   return(PL)
